labeltools.label_leaves_in_expr_with_numbered_interval_classes
==============================================================

.. autofunction:: abjad.tools.labeltools.label_leaves_in_expr_with_numbered_interval_classes.label_leaves_in_expr_with_numbered_interval_classes
